#!/usr/bin/perl
#########################################################################################################
# IP2Proxy Converter - IP Number Ranges To CIDR
#########################################################################################################
# Description: Reads the input_file and converts the ip_number to cidr and output as the below format:
#              "cidr","country_code","country_name"
#
# Usage: perl ip2proxy-to-cidr.pl IP2PROXY-IP-COUNTRY.CSV IP2PROXY-IP-COUNTRY-NEW.CSV
#
# Note: Perl requires the Net::CIDR package to be installed.
#
# There is no warranty or guarantee conveyed by the author/copyright holder of
# this script. By obtaining, installing, and using this program, you agree and
# understand that the author and copyright holder are not responsible for any
# damages caused under any conditions due to the malfunction of the script(s)
# on your server or otherwise.
#
# REVISION HISTORY
# ================
# 1.0.0   Initial Release
#
# Copyright (C) 2005-2016 IP2Location.com. All rights reserved.
#
#########################################################################################################

use strict;
use Socket;
use File::Basename qw(basename);
use Net::CIDR;

my $script_name = basename $0;

if (($#ARGV + 1) < 2)
{
	print "\nUsage: perl $script_name [input_file] [output_file]\n";
	exit();
}

my $inputfile = $ARGV[0];
my $outputfile = $ARGV[1];

open my $in, "<", $inputfile or die "Cannot open input file";
open my $out, ">", $outputfile or die "Cannot open output file";
binmode $in;
binmode $out;

while (<$in>)
{
	my $line = $_;
	
	if ($line =~ /^"(\d+)","(\d+)"(.*)/s)
	{
		my @cidr = Net::CIDR::range2cidr(&long2ip($1) . '-' . &long2ip($2));
		foreach (@cidr)
		{
			print $out '"' . $_ . '"' . $3;
		}
	}
}
close $in;
close $out;

sub long2ip
{
	return inet_ntoa(pack("N*", shift));
}
